OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Дададзены ў абранае",
    "Removed from favorites" : "Выдалены з абранага",
    "You added {file} to your favorites" : "Вы дадалі {file} у абранае",
    "You removed {file} from your favorites" : "Вы выдалілі {file} з абранага",
    "Favorites" : "Абранае",
    "File changes" : "Змены ў файлах",
    "Created by {user}" : "Створаны карыстальнікам {user}",
    "Changed by {user}" : "Зменены карыстальнікам {user}",
    "Deleted by {user}" : "Выдалены карыстальнікам {user}",
    "Restored by {user}" : "Адноўлены карыстальнікам {user}",
    "Renamed by {user}" : "Перайменаваны карыстальнікам {user}",
    "Moved by {user}" : "Перамешчаны карыстальнікам {user}",
    "\"remote account\"" : "\"аддалены ўліковы запіс\"",
    "You created {file}" : "Вы стварылі {file}",
    "You created an encrypted file in {file}" : "Вы стварылі зашыфраваны файл у {file}",
    "{user} created {file}" : "{user} стварыў(-ла) {file}",
    "{user} created an encrypted file in {file}" : "{user} стварыў(-ла) зашыфраваны файл у {file}",
    "{file} was created in a public folder" : "Файл {file} быў створаны ў публічнай папцы",
    "You changed {file}" : "Вы змянілі {file}",
    "You changed an encrypted file in {file}" : "Вы змянілі зашыфраваны файл у {file}",
    "{user} changed {file}" : "{user} змяніў(-ла) {file}",
    "{user} changed an encrypted file in {file}" : "{user} змяніў(-ла) зашыфраваны файл у {file}",
    "You deleted {file}" : "Вы выдалілі {file}",
    "You deleted an encrypted file in {file}" : "Вы выдалілі зашыфраваны файл у {file}",
    "{user} deleted {file}" : "{user} выдаліў(-ла) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} выдаліў(-ла) зашыфраваны файл у {file}",
    "You restored {file}" : "Вы аднавілі {file}",
    "{user} restored {file}" : "{user} аднавіў(-ла) {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Вы перайменавалі {oldfile} (схаваны) у {newfile} (схаваны)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Вы перайменавалі {oldfile} (схаваны) у {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Вы перайменавалі {oldfile} у {newfile} (схаваны)",
    "You renamed {oldfile} to {newfile}" : "Вы перайменавалі {oldfile} у {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} перайменаваў(-ла) {oldfile} (схаваны) у {newfile} (схаваны)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} перайменаваў(-ла) {oldfile} (схаваны) ў {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} перайменаваў(-ла) {oldfile} у {newfile} (схаваны)",
    "{user} renamed {oldfile} to {newfile}" : "{user} перайменаваў(-ла) {oldfile} у {newfile}",
    "You moved {oldfile} to {newfile}" : "Вы перамясцілі {oldfile} у {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} перамясціў(-ла) {oldfile} у {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл быў дададзены або выдалены з <strong>абраных</strong>",
    "Files" : "Файлы",
    "A file or folder has been <strong>changed</strong>" : "Файл або папка былі <strong>зменены</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Абраны файл або папка былі <strong>зменены</strong>",
    "Failed to authorize" : "Не ўдалося аўтарызавацца",
    "Invalid folder path" : "Памылковы шлях да папкі",
    "Folder not found" : "Папка не знойдзена",
    "The file cannot be found" : "Файл не знойдзены",
    "The destination path does not exist: %1$s" : "Шлях прызначэння не існуе: %1$s",
    "You do not have permission to create a file at the specified location" : "У вас няма дазволу на стварэнне файла ў пазначаным месцы",
    "The file could not be converted." : "Не ўдалося сканвертаваць файл.",
    "Could not get relative path to converted file" : "Не ўдалося атрымаць адносны шлях да сканвертаванага файла",
    "Limit must be a positive integer." : "Ліміт павінен быць дадатным цэлым лікам.",
    "The replacement character may only be a single character." : "Сімвалам замены можа быць толькі адзіночны сімвал.",
    "Filename sanitization already started." : "Ачыстка назваў файлаў ужо запушчана.",
    "No filename sanitization in progress." : "Ачыстка назваў файлаў не выконваецца.",
    "Favorite files" : "Абраныя файлы",
    "No favorites" : "Няма абраных",
    "More favorites" : "Больш абраных",
    "Accept" : "Прыняць",
    "Reject" : "Адхіліць",
    "Incoming ownership transfer from {user}" : "Уваходная перадача права ўласнасці ад карыстальніка {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Вы хочаце прыняць {path}?\n\nЗвярніце ўвагу: працэс перадачы пасля прыняцця можа заняць да 1 гадзіны.",
    "Ownership transfer denied" : "Перадача права ўласнасці адхілена",
    "Your ownership transfer of {path} was denied by {user}." : "Перадача права ўласнасці на {path} была адхілена карыстальнікам {user}.",
    "Ownership transfer failed" : "Перадача права ўласнасці не атрымалася",
    "Your ownership transfer of {path} to {user} failed." : "Перадача права ўласнасці на {path} карыстальніку {user} не атрымалася.",
    "The ownership transfer of {path} from {user} failed." : "Перадача права ўласнасці на {path} ад карыстальніка {user} не атрымалася.",
    "Ownership transfer done" : "Перадача права ўласнасці завершана",
    "Your ownership transfer of {path} to {user} has completed." : "Перадача права ўласнасці на {path} карыстальніку {user} завершана.",
    "The ownership transfer of {path} from {user} has completed." : "Перадача права ўласнасці на {path} ад карыстальніка {user} завершана.",
    "in %s" : "у %s",
    "Transferred from %1$s on %2$s" : "Перададзена з %1$s на %2$s",
    "File Management" : "Кіраванне файламі",
    "Home" : "Дадому",
    "Target folder does not exist any more" : "Мэтавая папка больш не існуе",
    "Reload current directory" : "Перазагрузіць бягучы каталог",
    "Go to the \"{dir}\" directory" : "Перайсці да каталога \"{dir}\"",
    "Current directory path" : "Бягучы шлях да каталога",
    "Share" : "Абагуліць",
    "Your have used your space quota and cannot upload files anymore" : "Вы выкарысталі сваю квоту прасторы і больш не можаце запампоўваць файлы",
    "You do not have permission to upload or create files here." : "У вас няма дазволу на запампоўванне або стварэнне файлаў тут.",
    "Drag and drop files here to upload" : "Перацягніце файлы сюды, каб запампаваць іх",
    "Favorite" : "Абранае",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Пераключыць выбар файла \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Пераключыць выбар папкі \"{displayName}\"",
    "File is loading" : "Файл загружаецца",
    "Folder is loading" : "Папка загружаецца",
    "Filename" : "Назва файла",
    "Folder name" : "Назва папкі",
    "This node is unavailable" : "Гэты вузел недаступны",
    "Another entry with the same name already exists." : "Запіс з такой назвай ужо існуе.",
    "Invalid filename." : "Памылковая назва файла.",
    "Rename file" : "Перайменаваць файл",
    "Folder" : "Папка",
    "Unknown file type" : "Невядомы тып файла",
    "{ext} image" : "Відарыс {ext}",
    "{ext} video" : "Відэа {ext}",
    "{ext} audio" : "Аўдыя {ext} ",
    "{ext} text" : "Тэкст {ext}",
    "Pending" : "У чаканні",
    "Unknown date" : "Невядомая дата",
    "Active filters" : "Актыўныя фільтры",
    "Remove filter" : "Выдаліць фільтр",
    "Today" : "Сёння",
    "Last 7 days" : "Апошнія 7 дзён",
    "Last 30 days" : "Апошнія 30 дзён",
    "This year ({year})" : "Гэты год ({year})",
    "Last year ({year})" : "Мінулы год ({year})",
    "Custom date range" : "Карыстальніцкі дыяпазон дат",
    "Search everywhere" : "Шукаць усюды",
    "Documents" : "Дакументы",
    "Spreadsheets" : "Табліцы",
    "Presentations" : "Прэзентацыі",
    "PDFs" : "PDF-файлы",
    "Folders" : "Папкі",
    "Audio" : "Аўдыя",
    "Images" : "Відарысы",
    "Videos" : "Відэа",
    "Filters" : "Фільтры",
    "Appearance" : "Знешні выгляд",
    "Show hidden files" : "Паказваць схаваныя файлы",
    "Show file type column" : "Паказаць слупок тыпу файла",
    "Show file extensions" : "Паказваць пашырэнні файлаў",
    "Crop image previews" : "Абразаць перадпрагляд малюнкаў",
    "General" : "Агульныя",
    "Sort favorites first" : "Спачатку паказваць абраныя",
    "Sort folders before files" : "Паказваць папкі перад файламі",
    "Default view" : "Прадвызначаны выгляд",
    "All files" : "Усе файлы",
    "Personal files" : "Асабістыя файлы",
    "Additional settings" : "Дадатковыя налады",
    "Actions" : "Дзеянні",
    "File actions" : "Дзеянні з файламі",
    "Selection" : "Выбар",
    "Select all files" : "Выбраць усе файлы",
    "Deselect all" : "Скасаваць выбар усіх",
    "Select or deselect" : "Выбраць або скасаваць выбар",
    "Select a range" : "Выбраць дыяпазон",
    "Navigation" : "Навігацыя",
    "Go to parent folder" : "Перайсці ў бацькоўскую папку",
    "Go to file above" : "Перайсці да файла вышэй",
    "Go to file below" : "Перайсці да файла ніжэй",
    "Go left in grid" : "Перайсці лявей па сетцы",
    "Go right in grid" : "Перайсці правей па сетцы",
    "View" : "Выгляд",
    "Toggle grid view" : "Пераключыць выгляд сеткі",
    "Show those shortcuts" : "Паказаць гэтыя спалучэнні клавіш",
    "Warnings" : "Папярэджанні",
    "Warn before changing a file extension" : "Папярэджваць перад зменай пашырэння файла",
    "WebDAV URL" : "URL-адрас WebDAV",
    "How to access files using WebDAV" : "Як атрымаць доступ да файлаў з дапамогай WebDAV",
    "Total rows summary" : "Зводка па ўсіх радках",
    "Toggle selection for all files and folders" : "Пераключыць выбар для ўсіх файлаў і папак",
    "Name" : "Назва",
    "File type" : "Тып файла",
    "Size" : "Памер",
    "Modified" : "Зменены",
    "{displayName}: failed on some elements" : "{displayName}: не атрымалася на некаторых элементах",
    "{displayName}: done" : "{displayName}: гатова",
    "{displayName}: failed" : "{displayName}: не атрымалася",
    "(selected)" : "(выбраны)",
    "List of files and folders." : "Спіс файлаў і папак.",
    "You have used your space quota and cannot upload files anymore." : "Вы выкарысталі сваю квоту прасторы і больш не можаце запампоўваць файлы.",
    "Column headers with buttons are sortable." : "Можна сартаваць па слупках, у загалоўку якіх ёсць кнопка.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Гэты спіс не апрацоўваецца цалкам з меркаванняў прадукцыйнасці. Файлы будуць апрацоўвацца па меры навігацыі па спісе.",
    "File not found" : "Файл не знойдзены",
    "_{count} selected_::_{count} selected_" : ["Выбраны {count}","Выбраны {count}","Выбрана {count}","Выбрана {count}"],
    "Search everywhere …" : "Шукаць усюды …",
    "Search here …" : "Шукаць тут …",
    "Search scope options" : "Параметры вобласці пошуку",
    "Search here" : "Шукаць тут",
    "Owner" : "Уладальнік",
    "{usedQuotaByte} used" : "Выкарыстана {usedQuotaByte}",
    "{used} of {quota} used" : "Выкарыстана {used} з {quota}",
    "{relative}% used" : "Выкарыстана {relative}%",
    "Could not refresh storage stats" : "Не ўдалося абнавіць статыстыку сховішча",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваша сховішча запоўнена, файлы больш нельга абнаўляць або сінхранізаваць!",
    "Storage information" : "Інфармацыя пра сховішча",
    "Storage quota" : "Квота сховішча",
    "New folder" : "Новая папка",
    "Create new folder" : "Стварыць новую папку",
    "This name is already in use." : "Гэта назва ўжо выкарыстоўваецца.",
    "Create" : "Стварыць",
    "Files starting with a dot are hidden by default" : "Файлы, якія пачынаюцца з кропкі, прадвызначана схаваныя",
    "Failed to start filename sanitization." : "Не ўдалося запусціць ачыстку назваў файлаў.",
    "Failed to refresh filename sanitization status." : "Не атрымалася абнавіць статус ачысткі назваў файла.",
    "Filename sanitization in progress." : "Ідзе ачыстка назваў файлаў.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "На дадзены момант ужо апрацавана {processedUsers} з {totalUsers} уліковых запісаў.",
    "Preparing …" : "Падрыхтоўка …",
    "Refresh" : "Абнавіць",
    "All files have been santized for Windows filename support." : "Усе назвы файлаў былі ачашчаны для падтрымкі ў Windows.",
    "Some files could not be sanitized, please check your logs." : "Некаторыя файлы не ўдалося ачысціць. Паглядзіце журналы.",
    "Sanitization errors" : "Памылкі ачысткі",
    "Not sanitized filenames" : "Неачышчаныя назвы файлаў",
    "Windows filename support has been enabled." : "Падтрымка назваў файлаў Windows уключана.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Хоць гэта і не дазваляе карыстальнікам ствараць новыя файлаў з назвамі, якія не падтрымліваюцца, існуючыя файлы яшчэ не пераймяноўваюцца і таму сінхранізацыя ў Windows можа быць парушана.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Вы можаце ўключыць перайменаванне файлаў з памылковымі назвамі. Яно будзе працаваць у фонавым рэжыме і можа заняць некаторы час.",
    "Please note that this may cause high workload on the sync clients." : "Звярніце ўвагу, што гэта можа прывесці да высокай нагрузкі на кліентаў сінхранізацыі.",
    "Limit" : "Ліміт",
    "This allows to configure how many users should be processed in one background job run." : "Дазваляе наладзіць, колькі карыстальнікаў павінна апрацоўвацца ў адным фонавым заданні.",
    "Sanitize filenames" : "Ачысціць назвы файлаў",
    "(starting)" : "(пачынаецца)",
    "Fill template fields" : "Запоўніце палі шаблону",
    "Submitting fields …" : "Адпраўка палёў …",
    "Submit" : "Адправіць",
    "Choose a file or folder to transfer" : "Выберыце файл або папку для перадачы",
    "Transfer" : "Перадаць",
    "Transfer {path} to {userid}" : "Перадаць {path} карыстальніку {userid}",
    "Invalid path selected" : "Выбраны памылковы шлях",
    "Unknown error" : "Невядомая памылка",
    "Ownership transfer request sent" : "Запыт на перадачу права ўласнасці адпраўлены",
    "Cannot transfer ownership of a file or folder you do not own" : "Немагчыма перадаць права ўласнасці на файл або папку, якімі вы не валодаеце",
    "Transfer ownership of a file or folder" : "Перадача права ўласнасці на файл або папку",
    "Choose file or folder to transfer" : "Выберыце файл або папку для перадачы",
    "Change" : "Змяніць",
    "New owner" : "Новы ўладальнік",
    "Keep {old}" : "Пакінуць {old}",
    "Keep without extension" : "Пакінуць без пашырэння",
    "Use {new}" : "Выкарыстоўваць {new}",
    "Remove extension" : "Выдаліць пашырэнне",
    "Change file extension" : "Змяніць пашырэнне файла",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Змена пашырэння файла з \"{old}\" на \"{new}\" можа зрабіць файл нечытэльным.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Выдаленне пашырэння файла \"{old}\" можа зрабіць файл нечытэльным.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Даданне пашырэння файла \"{new}\" можа зрабіць файл нечытэльным.",
    "Do not show this dialog again." : "Больш не паказваць гэта дыялогавае акно.",
    "Cancel" : "Скасаваць",
    "Rename" : "Перайменаваць",
    "Select file or folder to link to" : "Выберыце файл або каталог, на які трэба зрабіць спасылку",
    "Choose {file}" : "Выбраць {file}",
    "Files settings" : "Налады Файлаў",
    "Switch to list view" : "Пераключыцца ў выгляд спісу",
    "Switch to grid view" : "Пераключыцца ў выгляд сеткі",
    "The file could not be found" : "Файл не знойдзены",
    "Upload was cancelled by user" : "Карыстальнік скасаваў запампоўванне",
    "Not enough free space" : "Недастаткова вольнай прасторы",
    "Operation is blocked by access control" : "Аперацыя заблакіравана сістэмай кантролю доступу",
    "Error during upload: {message}" : "Памылка падчас запампоўвання: {message}",
    "Error during upload, status code {status}" : "Памылка падчас запампоўвання, код стану {status}",
    "Unknown error during upload" : "Невядомая памылка падчас запампоўвання",
    "Loading current folder" : "Загрузка бягучай папкі",
    "Retry" : "Паўтарыць спробу",
    "No files in here" : "Тут няма файлаў",
    "Upload some content or sync with your devices!" : "Запампуйце што-небудзь або сінхранізуйце са сваімі прыладамі!",
    "Go back" : "Назад",
    "Loading …" : "Загрузка …",
    "Your files" : "Вашы файлы",
    "Open in files" : "Адкрыць у Файлах",
    "File cannot be accessed" : "Немагчыма атрымаць доступ да файла",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Файл не знойдзены, або ў вас няма правоў на яго прагляд. Папрасіце адпраўніка абагуліць яго.",
    "No search results for “{query}”" : "Няма вынікаў пошуку па запыце \"{query}\"",
    "Search for files" : "Пошук файлаў",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дазволіць абмежоўваць назвы файлаў, каб забяспечыць сінхранізацыю файлаў з усімі кліентамі. Прадвызначана дазволены ўсе назвы файлаў, якія дзейнічаюць у POSIX (напрыклад, Linux або macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Пасля ўключэння сумяшчальнасці назваў файлаў з Windows існуючыя файлы больш нельга будзе змяняць, але іх уладальнік можа даць ім новыя правільныя назвы.",
    "Failed to toggle Windows filename support" : "Не ўдалося пераключыць падтрымку назваў файлаў Windows",
    "Files compatibility" : "Сумяшчальнасць файлаў",
    "Enforce Windows compatibility" : "Забяспечыць сумяшчальнасць з Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Будуць блакіравацца назвы файлаў, недазволеныя ў сістэмах Windows, напрыклад, з выкарыстаннем зарэзерваваных назваў або спецыяльных сімвалаў. Але гэта не забяспечыць сумяшчальнасць у плане адчувальнасці да рэгістра.",
    "Blank" : "Пусты",
    "Unable to create new file from template" : "Немагчыма стварыць новы файл з шаблона",
    "Pick a template for {name}" : "Выберыце шаблон для {name}",
    "Create a new file with the selected template" : "Стварыць файл на падставе выбранага шаблона",
    "Creating file" : "Стварэнне файла",
    "Save as {displayName}" : "Захаваць як {displayName}",
    "Save as …" : "Захаваць як …",
    "Converting files …" : "Канвертацыя файлаў …",
    "Failed to convert files: {message}" : "Не ўдалося сканвертаваць файлы: {message}",
    "All files failed to be converted" : "Не ўдалося сканвертаваць усе файлы",
    "One file could not be converted: {message}" : "Не ўдалося сканвертаваць адзін файл: {message}",
    "Failed to convert files" : "Не ўдалося сканвертаваць файлы",
    "Converting file …" : "Канвертацыя файла …",
    "File successfully converted" : "Файл паспяхова сканвертаваны",
    "Failed to convert file: {message}" : "Не ўдалося сканвертаваць файл: {message}",
    "Failed to convert file" : "Не ўдалося сканвертаваць файл",
    "Delete" : "Выдаліць",
    "Leave this share" : "Пакінуць гэта абагульванне",
    "Leave these shares" : "Пакінуць гэтыя абагульванні",
    "Disconnect storage" : "Адлучыць сховішча",
    "Disconnect storages" : "Адлучыць сховішчы",
    "Delete permanently" : "Выдаліць назаўжды",
    "Delete and unshare" : "Выдаліць і скасаваць абагульванне",
    "Delete file" : "Выдаліць файл",
    "Delete files" : "Выдаліць файлы",
    "Delete folder" : "Выдаліць папку",
    "Delete folders" : "Выдаліць папкі",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Вы збіраецеся назаўжды выдаліць {count} элемент","Вы збіраецеся назаўжды выдаліць {count} элементы","Вы збіраецеся назаўжды выдаліць {count} элементаў","Вы збіраецеся назаўжды выдаліць {count} элементаў"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Вы збіраецеся выдаліць {count} элемент","Вы збіраецеся выдаліць {count} элементы","Вы збіраецеся выдаліць {count} элементаў","Вы збіраецеся выдаліць {count} элементаў"],
    "Confirm deletion" : "Пацвердзіць выдаленне",
    "Download" : "Спампаваць",
    "The requested file is not available." : "Запытаны файл недаступны.",
    "The requested files are not available." : "Запытаныя файлы недаступны.",
    "Add to favorites" : "У абранае",
    "Remove from favorites" : "Выдаліць з абранага",
    "Add or remove favorite" : "Дадаць або выдаліць з абранага",
    "Move" : "Перамясціць",
    "Copy" : "Капіяваць",
    "Move or copy" : "Перамясціць або капіяваць",
    "Destination is not a folder" : "Месца прызначэння не з'яўляецца папкай",
    "This file/folder is already in that directory" : "Гэты файл/папка ўжо знаходзіцца ў гэтым каталогу",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Нельга перамясціць файл/папку ў сябе або ў падпапку самой сябе",
    "A file or folder with that name already exists in this folder" : "Файл або папка з такой назвай ужо існуе ў гэтай папцы",
    "The files are locked" : "Файлы заблакіраваны",
    "The file does not exist anymore" : "Файл больш не існуе",
    "Moving \"{source}\" to \"{destination}\" …" : "Перамяшчэнне \"{source}\" у \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Капіяванне \"{source}\" у \"{destination}\" …",
    "Choose destination" : "Выберыце прызначэнне",
    "Copy to {target}" : "Капіяваць у {target}",
    "Move to {target}" : "Перамясціць у {target}",
    "Move or copy operation failed" : "Не ўдалося перамясціць або скапіяваць",
    "Open folder {displayName}" : "Адкрыць папку {displayName}",
    "Open in Files" : "Адкрыць у Файлах",
    "Open locally" : "Адкрыць лакальна",
    "Failed to redirect to client" : "Не ўдалося перанакіраваць на кліент",
    "Open file locally" : "Адкрыць файл лакальна",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Файл павінен адкрыцца на вашай прыладзе. Калі не, праверце, ці ўсталявана ў вас праграма для ПК.",
    "Retry and close" : "Паўтарыць спробу і закрыць",
    "Open online" : "Адкрыць анлайн",
    "Details" : "Падрабязнасці",
    "View in folder" : "Праглядзець у папцы",
    "Type" : "Тып",
    "Created new folder \"{name}\"" : "Створана новая папка \"{name}\"",
    "Unable to initialize the templates directory" : "Немагчыма ініцыялізаваць каталог шаблонаў",
    "Create templates folder" : "Стварыць папку шаблонаў",
    "Templates" : "Шаблоны",
    "New template folder" : "Новая папка шаблонаў",
    "In folder" : "У папцы",
    "Search in all files" : "Пошук ва ўсіх файлах",
    "Search in folder: {folder}" : "Пошук у папцы: {folder}",
    "One of the dropped files could not be processed" : "Адзін з перацягнутых файлаў не ўдалося апрацаваць",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш браўзер не падтрымлівае Filesystem API. Каталогі не будуць запампаваныя",
    "No files to upload" : "Няма файлаў для запампоўвання",
    "Unable to create the directory {directory}" : "Немагчыма стварыць папку {directory}",
    "Some files could not be uploaded" : "Некаторыя файлы не ўдалося запампаваць",
    "Files uploaded successfully" : "Файлы паспяхова запампаваныя",
    "No files to process" : "Няма файлаў для апрацоўкі",
    "Files copied successfully" : "Файлы паспяхова скапіяваны",
    "Files moved successfully" : "Файлы паспяхова перамешчаны",
    "Some files could not be copied" : "Некаторыя файлы не ўдалося скапіяваць",
    "Some files could not be moved" : "Некаторыя файлы не ўдалося перамясціць",
    "Conflicts resolution skipped" : "Рашэнне канфліктаў прапушчана",
    "Upload cancelled" : "Запампоўванне скасавана",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не атрымалася перайменаваць \"{oldName}\", ён больш не існуе",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назва \"{newName}\" ужо выкарыстоўваецца ў папцы \"{dir}\". Выберыце іншую назву.",
    "Could not rename \"{oldName}\"" : "Не атрымалася перайменаваць \"{oldName}\"",
    "This operation is forbidden" : "Гэта аперацыя забаронена",
    "This folder is unavailable, please try again later or contact the administration" : "Гэта папка недаступна, паспрабуйце яшчэ раз пазней або звярніцеся да адміністратара",
    "Storage is temporarily not available" : "Сховішча часова недаступна",
    "Unexpected error: {error}" : "Нечаканая памылка: {error}",
    "_%n file_::_%n files_" : ["%n файл","%n файлы","%n файлаў","%n файлаў"],
    "_%n folder_::_%n folders_" : ["%n папка","%n папкі","%n папак","%n папак"],
    "_%n hidden_::_%n hidden_" : ["%n схаваны","%n схаваныя","%n схаваных","%n схаваных"],
    "Filename must not be empty." : "Назва файла не можа быць пустой.",
    "\"{char}\" is not allowed inside a filename." : "Сімвал \"{char}\" не дазволены ў назве файла.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\"  – гэта зарэзерваванае слова, якое не дазваляецца выкарыстоўваць у якасці назваў файлаў.",
    "\"{extension}\" is not an allowed filetype." : "Тып файла \"{extension}\" не дазволены.",
    "Filenames must not end with \"{extension}\"." : "Назвы файлаў не могуць заканчвацца на \"{extension}\".",
    "List of favorite files and folders." : "Спіс абраных файлаў і папак.",
    "No favorites yet" : "Пакуль няма абраных",
    "Files and folders you mark as favorite will show up here" : "Тут будуць адлюстроўвацца файлы і папкі, якія вы пазначаеце як абраныя",
    "List of your files and folders." : "Спіс вашых файлаў і папак.",
    "Folder tree" : "Дрэва папак",
    "List of your files and folders that are not shared." : "Спіс вашых неабагуленых файлаў і папак.",
    "No personal files found" : "Асабістых файлаў не знойдзена",
    "Files that are not shared will show up here." : "Тут будуць адлюстроўвацца неабагуленыя файлы.",
    "Recent" : "Нядаўнія",
    "List of recently modified files and folders." : "Спіс нядаўна змененых файлаў і папак.",
    "No recently modified files" : "Няма нядаўна змененых файлаў",
    "Files and folders you recently modified will show up here." : "Тут будуць адлюстроўвацца нядаўна змененыя вамі файлы і папкі.",
    "Search" : "Пошук",
    "Search results within your files." : "Вынікі пошуку ў вашых файлах.",
    "No entries found in this folder" : "У гэтай папцы не знойдзена запісаў",
    "Select all" : "Выбраць усе",
    "Upload too large" : "Запампоўка занадта вялікая",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Памер файлаў, якія вы спрабуеце запампаваць, перавышае максімальны дазволены памер для запампоўвання на гэтым серверы.",
    "%1$s (renamed)" : "%1$s (перайменаваны)",
    "renamed file" : "перайменаваны файл",
    "Upload (max. %s)" : "Запампоўванне (макс. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Пасля ўключэння сумяшчальнасці назваў файлаў з Windows існуючыя файлы больш нельга будзе змяняць, але іх уладальнік можа даць ім новыя правільныя назвы.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Пасля ўключэння гэтай налады таксама можна аўтаматычна пераносіць файлы, звярніцеся да дакументацыі па камандзе occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" перайменаваны ў \"{newName}\"",
    "Clear filter" : "Ачысціць фільтр",
    "\"{displayName}\" failed on some elements" : "Не ўдалося выканаць дзеянне \"{displayName}\" на некаторых элементах",
    "\"{displayName}\" batch action executed successfully" : "Пакетнае дзеянне \"{displayName}\" паспяхова выканана",
    "\"{displayName}\" action failed" : "Не ўдалося выканаць дзеянне \"{displayName}\"",
    "Submitting fields …" : "Адпраўка палёў …",
    "Shared by link" : "Абагулена праз спасылку",
    "Shared" : "Абагуленыя",
    "\"{displayName}\" action executed successfully" : "Дзеянне \"{displayName}\" паспяхова выканана",
    "Filter file names …" : "Фільтраваць назвы файлаў …",
    "Clipboard is not available" : "Буфер абмену недаступны",
    "WebDAV URL copied to clipboard" : "URL-адрас WebDAV скапіяваны ў буфер абмену",
    "Enable the grid view" : "Уключыць выгляд сеткі",
    "Enable folder tree" : "Уключыць дрэва папак",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Капіяваць у буфер абмену",
    "Use this address to access your Files via WebDAV" : "Выкарыстоўвайце гэты адрас для доступу да вашых файлаў праз WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Калі вы ўключылі 2FA, вам трэба стварыць і ўжываць новы пароль праграмы, націснуўшы тут.",
    "Prevent warning dialogs from open or reenable them." : "Забараніць папярэджанні або зноў уключыць іх.",
    "Show a warning dialog when changing a file extension." : "Паказваць папярэджанне пры змене пашырэння файла.",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "Speed up your Files experience with these quick shortcuts." : "Паскорце працу ў Файлах з дапамогай спалучэнняў клавіш.",
    "Open the actions menu for a file" : "Адкрыць меню дзеянняў для файла",
    "Rename a file" : "Перайменаваць файл",
    "Delete a file" : "Выдаліць файл",
    "Favorite or remove a file from favorites" : "Дадаць файл у абранае або выдаліць з абранага",
    "Manage tags for a file" : "Кіраванне тэгамі для файла",
    "Deselect all files" : "Скасаваць выбар усіх файлаў",
    "Select or deselect a file" : "Выбраць або скасаваць выбар файла",
    "Select a range of files" : "Выбраць дыяпазон файлаў",
    "Navigate to the parent folder" : "Перайсці ў бацькоўскую папку",
    "Navigate to the file above" : "Перайсці да файла вышэй",
    "Navigate to the file below" : "Перайсці да файла ніжэй",
    "Navigate to the file on the left (in grid mode)" : "Перайсці да файла злева (у рэжыме сеткі)",
    "Navigate to the file on the right (in grid mode)" : "Перайсці да файла справа (у рэжыме сеткі)",
    "Toggle the grid view" : "Пераключыць выгляд сеткі",
    "Open the sidebar for a file" : "Адкрыць бакавую панэль для файла",
    "You" : "Вы",
    "Shared multiple times with different people" : "Абагулены некалькі разоў з рознымі людзьмі",
    "Unable to change the favorite state of the file" : "Не ўдалося змяніць статус абранага для файла",
    "Error while loading the file data" : "Памылка пры загрузцы даных файла",
    "Tags" : "Тэгі",
    "Save as …" : "Захаваць як …",
    "Converting files …" : "Канвертацыя файлаў …",
    "Converting file …" : "Канвертацыя файла …",
    "Deletion cancelled" : "Выдаленне скасавана",
    "Edit locally" : "Рэдагаваць лакальна",
    "Moving \"{source}\" to \"{destination}\" …" : "Перамяшчэнне \"{source}\" у \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Капіяванне \"{source}\" у \"{destination}\" …",
    "(copy)" : "(копія)",
    "(copy %n)" : "(копія %n)",
    "Move cancelled" : "Перамяшчэнне скасавана",
    "Cancelled move or copy of \"{filename}\"." : "Аперацыя перамяшчэння або капіявання \"{filename}\" скасавана.",
    "Cancelled move or copy operation" : "Аперацыя перамяшчэння або капіявання скасавана",
    "Open details" : "Адкрыць падрабязнасці",
    "Photos and images" : "Фота і відарысы",
    "New folder creation cancelled" : "Стварэнне новай папкі скасавана",
    "This directory is unavailable, please check the logs or contact the administrator" : "Гэты каталог недаступны, праверце журналы або звярніцеся да адміністратара",
    "All folders" : "Усе папкі",
    "Open file sidebar" : "Адкрыць бакавую панэль файла",
    "Search everywhere …" : "Шукаць усюды …",
    "Search here …" : "Шукаць тут …",
    "Preparing …" : "Падрыхтоўка …"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
